@@ -19,7 +19,7 @@
 
 from . import *
 from .__version__ import __version__
-from ._base_client import ApiKeyFrom, FromConvertDot, RyzenthTools, UrHellFrom
+from ._base_client import ApiKeyFrom, FromConvertDot, RyzenthTools, UrHellFrom, fetch
 from ._client import RyzenthApiClient
 from ._new_client import RyzenthAuthClient
 
@@ -29,5 +29,6 @@ __all__ = [
     "RyzenthAuthClient",
     "UrHellFrom",
     "FromConvertDot",
-    "RyzenthTools"
+    "RyzenthTools",
+    "fetch"
 ]
