@@ -54,9 +54,11 @@ from .new_helper import (
     ChatsDeepseekAsync,
     ChatsGeminiAsync,
     ChatsGrokAsync,
+    ChatsHuggingFaceAsync,
     ChatsOpenAIAsync,
     ChatsQwenAsync,
     ChatsZaiAsync,
+    GhibliOrgAsync,
     ImagesFluxAsync,
     ImagesOpenAIAsync,
     ImagesOrgAsync,
@@ -77,6 +79,8 @@ class RyzenthOrg:
         self._api_key = api_key
         self._session = None
         self._closed = False
+        self.ghibli = GhibliOrgAsync(self)
+        self.hugging_chat = ChatsHuggingFaceAsync(self)
         self.flux_images = ImagesFluxAsync(self)
         self.zai_chat = ChatsZaiAsync(self)
         self.deepseek_chat = ChatsDeepseekAsync(self)
