@@ -5,7 +5,9 @@ from ._default_chats import ChatOrgAsync
 from ._default_images import ImagesOrgAsync
 from ._flux_images import ImagesFluxAsync
 from ._gemini_chats import ChatsGeminiAsync
+from ._ghibli_images import GhibliOrgAsync
 from ._grok_chats import ChatsGrokAsync
+from ._huggingface_chats import ChatsHuggingFaceAsync
 from ._old_gemini_chats import OldChatsGeminiAsync
 from ._openai_chats import ChatsOpenAIAsync
 from ._openai_images import ImagesOpenAIAsync
@@ -23,12 +25,14 @@ __all__ = [
     "ChatsGrokAsync",
     "ChatsCohereAsync",
     "ChatsDeepseekAsync",
+    "ChatsHuggingFaceAsync",
     "ChatsZaiAsync",
     "ImagesQwenAsync",
     "ImagesOrgAsync",
     "ImagesOpenAIAsync",
     "ImagesFluxAsync",
     "VideosQwenAsync",
+    "GhibliOrgAsync"
 ]
 
 __author__ = "Randy W @xtdevs, @xtsea"
