@@ -20,41 +20,59 @@
 
 import logging
 import os
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Union
 
 from .._benchmark import Benchmark
 from .._client import RyzenthApiClient
-from .._errors import EmptyResponseError, WhatFuckError
+from .._errors import (
+    AuthenticationError,
+    BadRequestError,
+    EmptyMessageError,
+    EmptyResponseError,
+    InitializeAPIError,
+    InternalServerOpenaiError,
+    WhatFuckError,
+)
 from .._export_class import ResponseResult
 from ..enums import ResponseType
-from ..helper import AutoRetry
+from ..helper import AutoRetry, HelpersUseStatic
+from ._models import RyzenthMessage
 
 
 class ChatsOpenAIAsync:
     def __init__(self, parent):
         self.parent = parent
         self._client = None
-        self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
+        self.msg = RyzenthMessage
+        self.file = HelpersUseStatic
+        self.logger = logging.getLogger(
+            f"{__name__}.{self.__class__.__name__}")
 
     def _get_client(self) -> RyzenthApiClient:
         if self._client is None:
-            api_key = getattr(self.parent, "_api_key", None) or os.environ.get("OPENAI_API_KEY")
+            api_key = getattr(
+                self.parent,
+                "_api_key",
+                None) or os.environ.get("OPENAI_API_KEY")
 
-            if not api_key or not isinstance(api_key, str) or not api_key.strip():
-                raise WhatFuckError("Missing or invalid API key for openAI client initialization.")
+            if not api_key or not isinstance(
+                    api_key, str) or not api_key.strip():
+                raise AuthenticationError(
+                    "Missing or invalid API key for openAI client initialization.")
             try:
                 self._client = RyzenthApiClient(
                     tools_name=["openai"],
                     api_key={"openai": [
-                      {
-                        "Authorization": f"Bearer {api_key}",
-                      }
+                        {
+                            "Authorization": f"Bearer {api_key}",
+                        }
                     ]},
                     rate_limit=100,
                     use_default_headers=True
                 )
             except Exception as e:
-                raise WhatFuckError(f"Failed to initialize API client: {e}") from e
+                raise InitializeAPIError(
+                    f"Failed to initialize API client: {e}") from e
         return self._client
 
     @Benchmark.performance(level=logging.DEBUG)
@@ -63,35 +81,35 @@ class ChatsOpenAIAsync:
         self,
         prompt: str | List[Dict] | Dict,
         *,
+        timeout: Union[int, float] = 100,
         model: str = "gpt-5",
         reasoning: Dict = None,
         instructions: str = None,
     ) -> ResponseResult:
         if not prompt:
-            raise WhatFuckError("Prompt is Required")
+            raise BadRequestError("Prompt is Required")
 
-        client = self._get_client()
         try:
-            response = await client.post(
-                tool="openai",
-                path="/responses",
-                timeout=30,
-                json={
-                    "input": prompt,
-                    "model": model,
-                    **({"reasoning": reasoning} if reasoning is not None else {}),
-                    **({"instructions": instructions} if instructions is not None else {})
-                },
-                use_type=ResponseType.JSON
-            )
-
-            if not response:
-                raise EmptyResponseError("Empty response from chat completion API")
-
-            return ResponseResult(client=client, response=response)
+            async with self._get_client() as client:
+                response = await client.post(
+                    tool="openai",
+                    path="/responses",
+                    timeout=timeout,
+                    json={
+                        "input": prompt,
+                        "model": model,
+                        **({"reasoning": reasoning} if reasoning is not None else {}),
+                        **({"instructions": instructions} if instructions is not None else {})
+                    },
+                    use_type=ResponseType.JSON
+                )
+                if not response:
+                    raise EmptyResponseError(
+                        "Empty response from chat completion API")
+                return ResponseResult(client=client, response=response)
         except Exception as e:
             self.logger.error(f"OpenAI chats failed: {e}")
-            raise WhatFuckError(f"OpenAI chats failed: {e}") from e
+            raise InternalServerOpenaiError(f"OpenAI chats failed: {e}") from e
         finally:
             pass
 
