@@ -23,16 +23,25 @@ from typing import Union
 
 from .._benchmark import Benchmark
 from .._client import RyzenthApiClient
-from .._errors import EmptyResponseError, WhatFuckError
+from .._errors import (
+    AuthenticationError,
+    EmptyMessageError,
+    EmptyResponseError,
+    InitializeAPIError,
+    InternalServerOpenaiError,
+    InvalidMessageError,
+    WhatFuckError,
+)
 from .._export_class import GeneratedImageOrVideo
 from ..enums import ResponseType
-from ..helper import AutoRetry
+from ..helper import AutoRetry, HelpersUseStatic
 
 
 class ImagesOpenAIAsync:
     def __init__(self, parent):
         self.parent = parent
         self._client = None
+        self.request = HelpersUseStatic
         self.logger = logging.getLogger(
             f"{__name__}.{self.__class__.__name__}")
 
@@ -45,7 +54,7 @@ class ImagesOpenAIAsync:
 
             if not api_key or not isinstance(
                     api_key, str) or not api_key.strip():
-                raise WhatFuckError(
+                raise AuthenticationError(
                     "Missing or invalid API key for openAI client initialization.")
             try:
                 self._client = RyzenthApiClient(
@@ -60,7 +69,7 @@ class ImagesOpenAIAsync:
                     use_default_headers=True
                 )
             except Exception as e:
-                raise WhatFuckError(
+                raise InitializeAPIError(
                     f"Failed to initialize API client: {e}") from e
         return self._client
 
@@ -74,7 +83,7 @@ class ImagesOpenAIAsync:
         model: str = "gpt-image-1",
     ) -> GeneratedImageOrVideo:
         if not prompt or not prompt.strip():
-            raise WhatFuckError("Prompt cannot be empty")
+            raise EmptyMessageError("Prompt cannot be empty")
 
         try:
             async with self._get_client() as client:
@@ -94,7 +103,7 @@ class ImagesOpenAIAsync:
                 return GeneratedImageOrVideo(client=client, content=response)
         except Exception as e:
             self.logger.error(f"Openai image generation failed: {e}")
-            raise WhatFuckError(f"Openai image generation failed: {e}") from e
+            raise InternalServerOpenaiError(f"Openai image generation failed: {e}") from e
         finally:
             pass
 
