@@ -20,42 +20,59 @@
 
 import logging
 import os
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Union
 
 from .._benchmark import Benchmark
 from .._client import RyzenthApiClient
-from .._errors import EmptyResponseError, InvalidMessageError, WhatFuckError
+from .._errors import (
+    AuthenticationError,
+    EmptyResponseError,
+    InitializeAPIError,
+    InternalServerQwenError,
+    InvalidMessageError,
+    WhatFuckError,
+)
 from .._export_class import ResponseResult
 from ..enums import ResponseType
-from ..helper import AutoRetry
+from ..helper import AutoRetry, HelpersUseStatic
+from ._models import RyzenthMessage
 
 
 class ChatsQwenAsync:
     def __init__(self, parent):
         self.parent = parent
         self._client = None
-        self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
+        self.msg = RyzenthMessage
+        self.file = HelpersUseStatic
+        self.logger = logging.getLogger(
+            f"{__name__}.{self.__class__.__name__}")
 
     def _get_client(self) -> RyzenthApiClient:
         if self._client is None:
-            api_key = getattr(self.parent, "_api_key", None) or os.environ.get("ALIBABA_API_KEY")
+            api_key = getattr(
+                self.parent,
+                "_api_key",
+                None) or os.environ.get("ALIBABA_API_KEY")
 
-            if not api_key or not isinstance(api_key, str) or not api_key.strip():
-                raise WhatFuckError("Missing or invalid API key for Alibaba client initialization.")
+            if not api_key or not isinstance(
+                    api_key, str) or not api_key.strip():
+                raise AuthenticationError(
+                    "Missing or invalid API key for Alibaba client initialization.")
             try:
                 self._client = RyzenthApiClient(
                     tools_name=["alibaba"],
                     api_key={"alibaba": [
-                      {
-                        "Authorization": f"Bearer {api_key}",
-                        "Content-Type": "application/json"
-                      }
+                        {
+                            "Authorization": f"Bearer {api_key}",
+                            "Content-Type": "application/json"
+                        }
                     ]},
                     rate_limit=100,
                     use_default_headers=True
                 )
             except Exception as e:
-                raise WhatFuckError(f"Failed to initialize API client: {e}") from e
+                raise InitializeAPIError(
+                    f"Failed to initialize API client: {e}") from e
         return self._client
 
     @Benchmark.performance(level=logging.DEBUG)
@@ -64,44 +81,39 @@ class ChatsQwenAsync:
         self,
         messages: List[Dict],
         *,
+        timeout: Union[int, float] = 100,
         model: str = "qwen-plus-2025-04-28",
         stream: bool = False,
         include_usage: bool = False,
         enable_thinking: bool = True,
     ) -> ResponseResult:
-        if not isinstance(messages, list) or len(messages) == 0:
+        if not isinstance(messages, list) or not messages:
             raise InvalidMessageError("Messages must be a non-empty list")
-        for idx, msg in enumerate(messages):
-            if not isinstance(msg, dict):
-                raise InvalidMessageError(f"Message at index {idx} must be a dict")
-            if "role" not in msg or "content" not in msg:
-                raise InvalidMessageError(f"Message at index {idx} must contain 'role' and 'content' keys")
 
-        client = self._get_client()
         try:
-            response = await client.post(
-                tool="alibaba",
-                path="/compatible-mode/v1/chat/completions",
-                timeout=30,
-                json={
-                    "model": model,
-                    "messages": messages,
-                    "stream": stream,
-                    "stream_options": {
-                        "include_usage": include_usage
+            async with self._get_client() as client:
+                response = await client.post(
+                    tool="alibaba",
+                    path="/compatible-mode/v1/chat/completions",
+                    timeout=timeout,
+                    json={
+                        "model": model,
+                        "messages": messages,
+                        "stream": stream,
+                        "stream_options": {
+                            "include_usage": include_usage
+                        },
+                        "enable_thinking": enable_thinking
                     },
-                    "enable_thinking": enable_thinking
-                },
-                use_type=ResponseType.JSON
-            )
-
-            if not response:
-                raise EmptyResponseError("Empty response from chat completion API")
-
-            return ResponseResult(client=client, response=response)
+                    use_type=ResponseType.JSON
+                )
+                if not response:
+                    raise EmptyResponseError(
+                        "Empty response from chat completion API")
+                return ResponseResult(client=client, response=response)
         except Exception as e:
             self.logger.error(f"Qwen chats failed: {e}")
-            raise WhatFuckError(f"Qwen chats failed: {e}") from e
+            raise InternalServerQwenError(f"Qwen chats failed: {e}") from e
         finally:
             pass
 
