@@ -1,3 +1,5 @@
+"""API is disabled move to domain new
+
 from Ryzenth._synchisded import RyzenthXSync
 from Ryzenth.types import QueryParameter, RequestXnxx, Username
 
@@ -24,16 +26,6 @@ def test_yt_username():
     )
     assert result is not None
 
-def test_hentai_anime():
-    ryz = RyzenthXSync("test", base_url="https://x-api-js.onrender.com/api")
-    result = ryz.send_downloader(
-        switch_name="hentai-anime",
-        params=None,
-        params_only=False,
-        on_render=True
-    )
-    assert result is not None
-
 def test_xnxxdl():
     ryz = RyzenthXSync("test", base_url="https://x-api-js.onrender.com/api")
     result = ryz.send_downloader(
@@ -45,3 +37,4 @@ def test_xnxxdl():
         on_render=True
     )
     assert result is not None
+"""
