@@ -18,7 +18,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
-from typing import Any, Optional
+from typing import Any, Callable, Optional
 
 from pydantic import BaseModel, Field
 
@@ -52,3 +52,14 @@ class RequestHumanizer(BaseModel):
     writing_style: str
     author_id: str
     timestamp: str
+
+class MakeFetch(BaseModel):
+    url: str
+    post: bool = False
+    head: bool = False
+    headers: Optional[dict] = None
+    evaluate: Optional[Callable] = None
+    object_flag: bool = False
+    return_json: bool = False
+    return_content: bool = False
+    return_json_and_obj: bool = False
